aboutsummaryrefslogtreecommitdiff
path: root/flake.nix
diff options
context:
space:
mode:
Diffstat (limited to 'flake.nix')
-rw-r--r--flake.nix11
1 files changed, 6 insertions, 5 deletions
diff --git a/flake.nix b/flake.nix
index 96b354b..1ffceff 100644
--- a/flake.nix
+++ b/flake.nix
@@ -76,8 +76,8 @@
};
};
- # Helper to create a NixOS system
- mkSystem = hostname:
+ # Helper to create a NixOS system with rice
+ mkSystem = hostname: rice:
nixpkgs.lib.nixosSystem {
inherit system;
specialArgs = {inherit inputs;};
@@ -91,6 +91,7 @@
}
./hosts/${hostname}/configuration.nix
./system
+ ./home/rices/${rice}/system.nix
home-manager.nixosModules.home-manager
nixowos.nixosModules.default
stylix.nixosModules.stylix
@@ -99,9 +100,9 @@
};
in {
nixosConfigurations = {
- kronos = mkSystem "kronos";
- herra = mkSystem "herra";
- mystra = mkSystem "mystra";
+ kronos = mkSystem "kronos" "nord-blue";
+ herra = mkSystem "herra" "cassette-futurism";
+ mystra = mkSystem "mystra" "nord-blue";
};
};
}